@@ -7,12 +7,19 @@ import time
 serverconf = dict(eval(open('server.conf', 'rb').read()))
 serverurl = serverconf['url']
 
+forum = None
+
 # And Base Templates
 
 m1 = jinja2.Template(
-    '<h1>账号邮箱变动</h1><br>原先的邮箱：{{ oldemail}} 将停用，改用 {{ newemail }} 作为新的邮箱<br><code>验证码:{{ code }}')
+    "<h1>账号邮箱变动</h1><br>原先的邮箱：{{ oldemail}} 将停用，改用 {{ newemail }} 作为新的邮箱<br><code>验证码:{{ code }}")
 
 
+def m2(body):
+    m2 = "<h2>你参与或星标的讨论有了新的回复</h2><a href='" + \
+        serverconf["url"] + "/notifications'>点击查看</a><p>" + body + "</p>"
+    return m2
+
 def c():
     # Get Configs File
     serverconf = dict(eval(open('server.conf', 'rb').read()))
@@ -26,7 +33,6 @@ def getTimer(timetime, simple=True):
         return time.strftime("%Y-%m-%d %H:%M:%S", time.localtime(int(timetime)))
 
 
-
 def getTemplates(
         body='',
         title='',
@@ -43,7 +49,8 @@ def getTemplates(
             userObj=userObj,
             webtitle=serverconf['stuoe_name'],
             js=serverconf['js'],
-            auth=auth)
+            auth=auth,
+            loginuser_menu=forum.loginuser_menu)
     else:
         nav = jinja2.Template(
             open(
@@ -87,9 +94,9 @@ def getTemplates(
             auth=auth)
 
 
-def gethome(auth=True, userObj='', tagslist='', postlist='', get_avater='',title=''):
+def gethome(auth=True, userObj='', tagslist='', postlist='', get_avater='', title='', options=''):
     body = jinja2.Template(open('storage/templates/index.html',
-                                'r', encoding="utf-8").read()).render(webtitle=serverconf['stuoe_name'], des=serverconf['stuoe_des'], userObj=userObj, tagslist=tagslist, postlist=list(postlist), get_avater=get_avater,auth=auth)
+                                'r', encoding="utf-8").read()).render(webtitle=serverconf['stuoe_name'], des=serverconf['stuoe_des'], userObj=userObj, tagslist=tagslist, postlist=postlist, get_avater=get_avater, auth=auth, options=options, some_sidebar=forum.some_sidebar)
     return getTemplates(auth=auth, title=title, body=body, userObj=userObj, base2=True)
 
 
@@ -165,7 +172,9 @@ def getPost(
         getTimer=getTimer,
         len=len,
         auth=auth,
-        userObj=userObj)
+        userObj=userObj,
+        int=int,
+        post_menu=forum.post_menu)
     return getTemplates(
         body=body,
         auth=auth,
